@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <QLocale>
 #include <QtTest>
@@ -68,7 +54,7 @@ private Q_SLOTS:
 
     void testPieceDataLoading()
     {
-        ChunkManager cman(tor, creator.tempPath(), creator.dataPath(), true, 0);
+        ChunkManager cman(tor, creator.tempPath(), creator.dataPath(), true, nullptr);
         Chunk *c = cman.getChunk(0);
         QVERIFY(c);
 
@@ -97,7 +83,7 @@ private Q_SLOTS:
 #ifndef Q_CC_MSVC
     void testBusErrorHandling()
     {
-        ChunkManager cman(tor, creator.tempPath(), creator.dataPath(), true, 0);
+        ChunkManager cman(tor, creator.tempPath(), creator.dataPath(), true, nullptr);
         Chunk *c = cman.getChunk(0);
         QVERIFY(c);
 
